==> rd2020-element-highlight-1.0.0.tgz: package/webpack.config.js <==
const { name } = require('./package.json');
const webpack = require('webpack');
const HtmlWebpackPlugin = require('html-webpack-plugin');
const path = require('path');
const { uuid } = require('uuidv4');
const MinifyPlugin = require("babel-minify-webpack-plugin");
const { camelCase } = require("camel-case");

const webpackDevServerRun = process.argv[1].indexOf('webpack-dev-server') !== -1;
const pkgName = name.replce('@thinkeloquent/rd2020-', '');

const local = {
  optimization: {
    splitChunks: {
      chunks: 'async',
      minSize: 30000,
      maxSize: 0,
      minChunks: 1,
      maxAsyncRequests: 6,
      maxInitialRequests: 4,
      automaticNameDelimiter: '~',
      cacheGroups: {
        defaultVendors: {
          test: /[\\/]node_modules[\\/]/,
          priority: -10
        },
        default: {
          minChunks: 2,
          priority: -20,
          reuseExistingChunk: true
        }
      }
    }
  },
  devServer: {
    compress: true,
    port: 9000,
  },
  watchOptions: {
    aggregateTimeout: 200,
    poll: 1000
  },
  plugins: [
    new HtmlWebpackPlugin({
      title: 'My App',
      filename: 'index.html',
      template: './webpack-devserver.html'
    }),
    new webpack.DefinePlugin({
      'process.env.BUILD_ID': JSON.stringify(uuid()),
      'process.env.AMD': JSON.stringify(true)
    })
  ]
};

const distBuild = {
  performance: {
    hints: false,
    maxEntrypointSize: Infinity,
    maxAssetSize: Infinity
  },
  optimization: {
    removeAvailableModules: false,
    removeEmptyChunks: false,
    splitChunks: false,
  },
  plugins: [
    new MinifyPlugin({
      "evaluate": false,
      "mangle": {
        "keepFnName": true
      },
      "keepFnName": true
    }),
    new webpack.DefinePlugin({
      'process.env.BUILD_ID': JSON.stringify(uuid()),
      'process.env.AMD': JSON.stringify(true)
    })
  ]
};

const defaultConfig = () => ({
  mode: 'development',
  devtool: 'source-map',
  entry: './src/index.js',
  ...(
    webpackDevServerRun ? local : distBuild
  ),
  output: {
    path: path.resolve(__dirname, 'dist'),
    filename: `${pkgName}.bundle.js`
  },
  module: {
    rules: [
      {
        test: /\.m?js$/,
        exclude: /(node_modules|bower_components)/,
        use: {
          loader: 'babel-loader',
          options: {
            presets: [
              '@babel/preset-env',
              '@babel/preset-react'
            ]
          }
        }
      },
      {
        test: /\.svg$/,
        loader: 'svg-inline-loader'
      },
    ]
  }
});

const umdConfig = () => ({
  ...defaultConfig(),
  output: {
    path: path.resolve(__dirname, 'dist'),
    filename: `${pkgName}.bundle.js`,
    library: camelCase(pkgName),
    libraryTarget: 'umd'
  }
})

module.exports = webpackDevServerRun ? umdConfig() : [
  defaultConfig(),
  umdConfig(),
];

==> rd2020-element-highlight-1.1.0.tgz: package/webpack.config.js <==
const { name } = require('./package.json');
const webpack = require('webpack');
const HtmlWebpackPlugin = require('html-webpack-plugin');
const path = require('path');
const { uuid } = require('uuidv4');
const MinifyPlugin = require("babel-minify-webpack-plugin");
const { camelCase } = require("camel-case");

const webpackDevServerRun = process.argv[1].indexOf('webpack-dev-server') !== -1;
const pkgName = name.replace('@thinkeloquent/rd2020-', '');

const local = {
  optimization: {
    splitChunks: {
      chunks: 'async',
      minSize: 30000,
      maxSize: 0,
      minChunks: 1,
      maxAsyncRequests: 6,
      maxInitialRequests: 4,
      automaticNameDelimiter: '~',
      cacheGroups: {
        defaultVendors: {
          test: /[\\/]node_modules[\\/]/,
          priority: -10
        },
        default: {
          minChunks: 2,
          priority: -20,
          reuseExistingChunk: true
        }
      }
    }
  },
  devServer: {
    compress: true,
    port: 9000,
  },
  watchOptions: {
    aggregateTimeout: 200,
    poll: 1000
  },
  plugins: [
    new HtmlWebpackPlugin({
      title: 'My App',
      filename: 'index.html',
      template: './webpack-devserver.html'
    }),
    new webpack.DefinePlugin({
      'process.env.BUILD_ID': JSON.stringify(uuid()),
      'process.env.AMD': JSON.stringify(true)
    })
  ]
};

const distBuild = {
  performance: {
    hints: false,
    maxEntrypointSize: Infinity,
    maxAssetSize: Infinity
  },
  optimization: {
    removeAvailableModules: false,
    removeEmptyChunks: false,
    splitChunks: false,
  },
  plugins: [
    new MinifyPlugin({
      "evaluate": false,
      "mangle": {
        "keepFnName": true
      },
      "keepFnName": true
    }),
    new webpack.DefinePlugin({
      'process.env.BUILD_ID': JSON.stringify(uuid()),
      'process.env.AMD': JSON.stringify(true)
    })
  ]
};

const defaultConfig = () => ({
  mode: 'development',
  devtool: 'source-map',
  entry: './src/index.js',
  ...(
    webpackDevServerRun ? local : distBuild
  ),
  output: {
    path: path.resolve(__dirname, 'dist'),
    filename: `${pkgName}.bundle.js`
  },
  module: {
    rules: [
      {
        test: /\.m?js$/,
        exclude: /(node_modules|bower_components)/,
        use: {
          loader: 'babel-loader',
          options: {
            presets: [
              '@babel/preset-env',
              '@babel/preset-react'
            ]
          }
        }
      },
      {
        test: /\.svg$/,
        loader: 'svg-inline-loader'
      },
    ]
  }
});

const umdConfig = () => ({
  ...defaultConfig(),
  output: {
    path: path.resolve(__dirname, 'dist'),
    filename: `${pkgName}.bundle.js`,
    library: camelCase(pkgName),
    libraryTarget: 'umd'
  }
})

module.exports = webpackDevServerRun ? umdConfig() : [
  defaultConfig(),
  umdConfig(),
];
